#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)38 1.14 src/ll/config_editor/cgi-bin/show_tab_panel_machine_env.pl, ll.config, ll_rrnep2, rrnep21206a 10/14/10 13:11:13\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(1);

my @normal_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machine_env"}->[0]};
my @editable_tables_by_nodeID = @{LLUtil::ALL_TABLES->{"tab_panel_machine_env"}->[1]};
my @normal_tables_by_fsID = @{LLUtil::ALL_TABLES->{"tab_panel_machine_env"}->[2]};
my @editable_tables_by_fsID = @{LLUtil::ALL_TABLES->{"tab_panel_machine_env"}->[3]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_machine_env.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

# Connect to db
my $dbh = get_dbh(1);
if(!defined($dbh))
{
	error_and_exit($dbh->errstr);
}

# Get default node id and name
my $default_node_id = undef;
my $default_node_name = undef;

# Get node id and name
my $sql_str="select nodeID,hostname from TLL_Nodelist";
my $sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down=();
while($sth->fetch())
{
	if( (!defined($default_node_id)) && ($name eq "default" || $name eq "Default") )
	{
		$default_node_id = $id;
		$default_node_name = $name;
	}
	else
	{
		my %pair = (id => $id, name => $name);
		push @pull_down, \%pair;
	}
}
if(defined($default_node_id))
{
	my %pair = (id => $default_node_id, name => $default_node_name);
	@pull_down = (\%pair, @pull_down);
}
elsif(scalar(@pull_down) > 0)
{
	my %pair = %{$pull_down[0]};
	$default_node_id = $pair{"id"};
	$default_node_name = $pair{"name"};
}
$tmpl->param(pull_down => \@pull_down);

# Show normal tables
foreach my $table (@normal_tables_by_nodeID)
{
	my @table_items = ();
	my $ary_ref = undef;
	if(defined($default_node_id))
	{
		$sql_str="select * from ".$table." where nodeID=".$default_node_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		$ary_ref = $sth->fetchrow_arrayref;
	}

	if(!defined($ary_ref))
	{
		$sql_str="select * from ".$table.get_only_one($db_conn);
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
	}

	for(my $m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		my $default = "";
		my $value = "";
		if(defined($ary_ref))
		{
			$value = $ary_ref->[$m];
		}

		my %item = (id => $table."-".$sth->{NAME}->[$m],
			    name => $table."-".$sth->{NAME}->[$m],
			    title => $table."-".$sth->{NAME}->[$m],
			    display_name => $sth->{NAME}->[$m],
			    value => $value,
			    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
			    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
			    orig_value => $value,
			    default => $default);
		push @table_items, \%item;
	}
		
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-id" => $default_node_id);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
		
}

foreach my $table (@editable_tables_by_nodeID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table.get_only_one($db_conn);
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);

	if(defined($default_node_id))
	{
		$sql_str="select * from ".$table." where nodeID=".$default_node_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		my $idx = 0;
		my @rows = ();
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			my @columns = ();
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				my %col_item = (name => $sth->{NAME}->[$i],
						title => $sth->{NAME}->[$i],
						value => $ary_ref->[$i],
						orig_name => "orig-".$sth->{NAME}->[$i],
						orig_value => $ary_ref->[$i]);
				push @columns, \%col_item;
			}
			
			my %row_item = (columns => \@columns);
			push @rows, \%row_item;
			$idx++;
			
		}
		$tmpl->param($table."_rows" => \@rows);
		$tmpl->param($table."-id" => $default_node_id);		
	}
}

my($fsID);
if(defined($default_node_id))
{
	
	$sql_str="select fsID from TLLR_CFGFileSysMon where nodeID=".$default_node_id;
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	$sth->bind_columns(undef,\$fsID);
	if($sth->fetch())
	{
	}

	if(!defined($fsID))
	{
		$sql_str="insert into TLLR_CFGFileSysMon (nodeID) values(".$default_node_id.")";
		if(!defined($dbh->do($sql_str)))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		$fsID = $dbh->last_insert_id(undef,undef,undef,undef);
		debug_log("insert new record to TLLR_CFGFileSysMon, fsID:".$fsID);
		
	}
	
}

foreach my $table (@normal_tables_by_fsID)
{
	my @table_items = ();
	if(defined($default_node_id))
	{
		$sql_str="select * from ".$table." where fsID=".$fsID;
	}
	else
	{
		$sql_str="select * from ".$table.get_only_one($db_conn);
	}
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $ary_ref = $sth->fetchrow_arrayref;
	my $m;
	if(defined($ary_ref))
	{
		for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
		{
			if(uc($sth->{NAME}->[$m]) ne uc("nodeID"))
			{
				#$sth->{TYPE}->[$m]
				my %item = (id => $table."-".$sth->{NAME}->[$m],
					    name => $table."-".$sth->{NAME}->[$m],
					    title => $table."-".$sth->{NAME}->[$m],
					    display_name => $sth->{NAME}->[$m],
					    value => $ary_ref->[$m],
					    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
					    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
					    orig_value => $ary_ref->[$m]);
				push @table_items, \%item;
			}
		}
	}
	else
	{
		$sql_str="select * from ".$table.get_only_one($db_conn);
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
		{
			#$sth->{TYPE}->[$m]
			my %item = (id => $table."-".$sth->{NAME}->[$m],
				    name => $table."-".$sth->{NAME}->[$m],
				    title => $table."-".$sth->{NAME}->[$m],
				    display_name => $sth->{NAME}->[$m],
				    value => "",
				    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
				    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
				    orig_value => "");
			push @table_items, \%item;
		}
	}
		
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-id" => $fsID);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
		
}

foreach my $table (@editable_tables_by_fsID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table.get_only_one($db_conn);
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]);
	
	if(defined($fsID))
	{
		$sql_str="select * from ".$table." where fsID=".$fsID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		my $idx = 0;
		my @rows = ();
		while(my $ary_ref = $sth->fetchrow_arrayref)
		{
			my @columns = ();
			my $i;
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				my %col_item = (name => $sth->{NAME}->[$i],
						title => $sth->{NAME}->[$i],
						value => $ary_ref->[$i],
						orig_name => "orig-".$sth->{NAME}->[$i],
						orig_value => $ary_ref->[$i]);
				push @columns, \%col_item;
			}
			
			my %row_item = (columns => \@columns);
			push @rows, \%row_item;
			$idx++;
		}
		$tmpl->param($table."_rows" => \@rows);
		$tmpl->param($table."-id" => $fsID);
	}
}

$sth->finish();
$dbh->disconnect();

print "Content-type: text/html\n\n";
print $tmpl->output;

