#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)41 1.11 src/ll/config_editor/cgi-bin/show_tab_panel_multicluster.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:37:40\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(1);

my @normal_tables_by_clusterID = @{LLUtil::ALL_TABLES->{"tab_panel_multicluster"}->[0]};
# The primary key of the following 5 tables is the combination of 3 fields.
my @editable_tables_by_clusterID = @{LLUtil::ALL_TABLES->{"tab_panel_multicluster"}->[1]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_multicluster.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

# Connect to db
my $dbh = get_dbh(1);
if(!defined($dbh))
{
	error_and_exit($dbh->errstr);
}

# Get default cluster id and name
my $default_cluster_id = undef;

# Get cluster id and name
my $sql_str="select clusterID,name from TLL_Cluster;";
my $sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down=();
while($sth->fetch())
{
	if($name eq "default" || $name eq "Default")
	{
		$default_cluster_id = $id;
	}
	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
}
$tmpl->param(pull_down => \@pull_down);

# Show normal tables
foreach my $table (@normal_tables_by_clusterID)
{
	my @table_items = ();
	my $ary_ref = undef;
	if(defined($default_cluster_id))
	{
		$sql_str="select * from ".$table." where clusterID=".$default_cluster_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		
		$ary_ref = $sth->fetchrow_arrayref;
	}
	if(!defined($ary_ref))
	{
		$sql_str="select * from ".$table.get_only_one($db_conn);
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
	}
	
	for(my $m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		if(uc($sth->{NAME}->[$m]) ne uc("classListType")
		   && uc($sth->{NAME}->[$m]) ne uc("groupListType")
		   && uc($sth->{NAME}->[$m]) ne uc("userListType")
		   && uc($sth->{NAME}->[$m]) ne uc("lastCFGMod")
		   && uc($sth->{NAME}->[$m]) ne uc("lldbVersion"))
		{
			my $default = "";
			if(defined($default_cluster_id) && defined($ary_ref) && exists $ary_ref->[$m])
			{
				$default = $ary_ref->[$m];
			}

			#$sth->{TYPE}->[$m]
			my %item = (id => $table."-".$sth->{NAME}->[$m],
				    name => $table."-".$sth->{NAME}->[$m],
				    title => $table."-".$sth->{NAME}->[$m],
				    display_name => $sth->{NAME}->[$m],
				    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
				    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
				    default => $default);
			push @table_items, \%item;
		}
	}
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
	
}

foreach my $table (@editable_tables_by_clusterID)
{
	my @table_display_items = ();
	my @table_input_items = ();
	$sql_str="select * from ".$table.get_only_one($db_conn);
	$sth=$dbh->prepare($sql_str);
	if(!defined($sth->execute()))
	{
		print "Content-type: text/html\n\n";
		$tmpl->param(error_string => $dbh->errstr);
		print $tmpl->output;
		exit 1;
	}
	my $m;
	for($m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		#$sth->{TYPE}->[$m]
		my %item1 = (display_name => $sth->{NAME}->[$m]);
		push @table_display_items, \%item1;
		my %item2 = (name => $sth->{NAME}->[$m],
			     title => $sth->{NAME}->[$m]);
		push @table_input_items, \%item2;
	}
	$tmpl->param($table."_display_items" => \@table_display_items);
	$tmpl->param($table."_input_items" => \@table_input_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]."-".$sth->{NAME}->[1]."-".$sth->{NAME}->[2]);
	
	my $default_str = "";
	if(defined($default_cluster_id))
	{
		$sql_str = "select * from ".$table." where clusterID=".$default_cluster_id;
		$default_str = get_default_keyword_str($dbh,$sql_str,$table);
	}
	$tmpl->param($table."_default_str" => $default_str);
}

$sth->finish();
$dbh->disconnect();


print "Content-type: text/html\n\n";
print $tmpl->output;

